@@ -4,6 +4,7 @@ import importlib.resources
 from pathlib import Path
 import random
 import string
+import os
 
 Shared = Munch()
 
@@ -17,7 +18,15 @@ with importlib.resources.path('cap', 'VERSION') as path:
     Shared.runtime.capVersion = Path(path).read_text()
 Shared.runtime.hailVersion = 'ToBeSet'
 Shared.runtime.sparkVersion = 'ToBeSet'
+Shared.runtime.sparkConfig = 'ToBeSet'
 Shared.runtime.dateTime = str(datetime.now().strftime("%Y/%m/%d-%H:%M:%S"))
+Shared.runtime.environment = Munch()
+
+for envVar in ['CAP_DIR', 'PYSPARK_PYTHON', 'PYSPARK_PYTHON', 'HAIL_HOME', 'SPARK_HOME']:
+    if envVar in os.environ:
+        Shared.runtime.environment[envVar] = os.environ[envVar]
+    else:
+        Shared.runtime.environment[envVar] = '__NOT_SET__'
 
 Shared.fileSystem = None
 
